var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { asBoolean, asObject, asOptional } from 'cleaners';
import { makeReactNativeDisklet } from 'disklet';
import * as React from 'react';
import { Image, Linking, Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import * as Assets from '../../assets/';
import s from '../../common/locales/strings';
import { fetchInfo } from '../../util/network';
import { withTheme } from '../services/ThemeContext';
const APPID_INFO_FILE = 'appIdInfo.json';
const asAppIdInfo = asObject({ hidePoweredBy: asOptional(asBoolean, false) });
const disklet = makeReactNativeDisklet();
class HeaderParentButtonsComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handlePress = () => {
            const { parentButton } = this.props.branding;
            if (parentButton != null)
                parentButton.callback();
        };
        this.state = {
            hidePoweredBy: false
        };
    }
    componentDidMount() {
        return __awaiter(this, void 0, void 0, function* () {
            const { appId } = this.props.branding;
            if (appId != null && appId !== '') {
                let appIdInfo;
                try {
                    const json = yield disklet.getText(APPID_INFO_FILE);
                    appIdInfo = asAppIdInfo(JSON.parse(json));
                }
                catch (e) {
                    console.log(e.message);
                    console.log('Failed to read appIdInfo.json. Failure ok');
                }
                if (appIdInfo == null) {
                    try {
                        const result = yield fetchInfo(`v1/appIdInfo/${appId}`);
                        appIdInfo = asAppIdInfo(yield result.json());
                        disklet.setText(APPID_INFO_FILE, JSON.stringify(appIdInfo));
                    }
                    catch (e) {
                        console.log(e.message);
                        console.log('Failed to fetch appIdInfo. Failure ok');
                        return;
                    }
                }
                const { hidePoweredBy } = appIdInfo;
                this.setState({ hidePoweredBy });
            }
        });
    }
    render() {
        const { parentButton, appId } = this.props.branding;
        const { hidePoweredBy } = this.state;
        const openEdgeSite = () => __awaiter(this, void 0, void 0, function* () { return yield Linking.openURL(s.strings.edge_site); });
        const styles = getStyles(this.props.theme);
        return (React.createElement(View, { style: styles.container },
            parentButton && parentButton.text && (React.createElement(TouchableOpacity, { onPress: this.handlePress },
                React.createElement(View, { style: styles.leftButtonContainer },
                    React.createElement(Text, { style: parentButton.style || styles.leftButtonText }, parentButton.text)))),
            React.createElement(View, { style: styles.spacer }),
            appId && !hidePoweredBy && (React.createElement(TouchableOpacity, { onPress: openEdgeSite },
                React.createElement(View, { style: styles.rightButtonContainer },
                    React.createElement(Text, { style: styles.rightButtonText }, s.strings.powered_by),
                    React.createElement(Image, { source: Assets.LOGO_SMALL, resizeMode: "contain", style: styles.image }))))));
    }
}
export const HeaderParentButtons = withTheme(HeaderParentButtonsComponent);
const getStyles = cacheStyles((theme) => ({
    container: {
        top: theme.rem(2),
        marginLeft: theme.rem(1),
        marginRight: theme.rem(1),
        flexDirection: 'row'
    },
    leftButtonContainer: {
        justifyContent: 'center',
        alignContents: 'center',
        height: theme.rem(2)
    },
    leftButtonText: {
        fontFamily: theme.fontFaceDefault,
        color: theme.primaryText,
        fontSize: theme.rem(1)
    },
    rightButtonContainer: {
        justifyContent: 'flex-end',
        alignContents: 'flex-end',
        height: theme.rem(2)
    },
    rightButtonText: {
        color: theme.primaryText,
        fontSize: theme.rem(0.5),
        textAlign: 'right'
    },
    spacer: {
        flex: 1
    },
    image: {
        width: theme.rem(4.5),
        height: theme.rem(1.25)
    }
}));
