import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import s from '../../common/locales/strings';
import { withTheme } from '../services/ThemeContext';
import { ModalCloseArrow } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
import { TitleText } from '../themed/ThemedText';
class SecurityAlertsModalComponent extends React.Component {
    render() {
        const { bridge } = this.props;
        return (React.createElement(ThemedModal, { bridge: bridge, warning: true, onCancel: () => bridge.resolve(undefined) },
            React.createElement(TitleText, null, s.strings.alert_modal_title),
            this.renderList(),
            React.createElement(ModalCloseArrow, { onPress: () => bridge.resolve(undefined) })));
    }
    renderList() {
        const { messages } = this.props;
        const out = [];
        let isFirst = true;
        for (const username of Object.keys(messages)) {
            const { otpResetPending } = messages[username];
            if (otpResetPending) {
                out.push(this.renderRow(username, true, isFirst));
                isFirst = false;
            }
        }
        for (const username of Object.keys(messages)) {
            const { pendingVouchers = [] } = messages[username];
            if (pendingVouchers.length > 0) {
                out.push(this.renderRow(username, false, isFirst));
                isFirst = false;
            }
        }
        return out;
    }
    renderRow(username, isReset, isFirst) {
        const { bridge, theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(TouchableOpacity, { key: (isReset ? 'reset:' : 'voucher:') + username, style: isFirst ? styles.row : styles.rowBorder, onPress: () => {
                this.props.selectUser(username);
                bridge.resolve(undefined);
            } },
            React.createElement(FontAwesome, { color: isReset ? theme.dangerText : theme.warningText, name: "exclamation-triangle", size: theme.rem(1.5), style: styles.rowIcon }),
            React.createElement(Text, { style: styles.rowText },
                React.createElement(Text, { style: styles.bold },
                    isReset
                        ? s.strings.alert_modal_reset
                        : s.strings.alert_modal_voucher,
                    username),
                s.strings.alert_modal_action),
            React.createElement(AntDesignIcon, { color: theme.iconTappable, name: "right", size: theme.rem(1), style: styles.rowIcon })));
    }
}
const getStyles = cacheStyles((theme) => ({
    row: {
        alignItems: 'center',
        flexDirection: 'row'
    },
    rowBorder: {
        alignItems: 'center',
        borderTopColor: theme.lineDivider,
        borderTopWidth: theme.thinLineWidth,
        flexDirection: 'row',
        marginTop: theme.rem(0.5),
        paddingTop: theme.rem(0.5)
    },
    rowIcon: {
        margin: theme.rem(0.5)
    },
    rowText: {
        color: theme.primaryText,
        flexGrow: 1,
        flexShrink: 1,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5)
    },
    bold: {
        fontWeight: 'bold'
    }
}));
export const SecurityAlertsModal = withTheme(SecurityAlertsModalComponent);
