import * as React from 'react';
import { View } from 'react-native';
import s from '../../common/locales/strings';
import * as Styles from '../../styles/index';
import { useSelector } from '../../types/ReduxTypes';
import { MaybeProvideLoginUi } from '../publicApi/LoginUiProvider';
import { ChangePasswordScene, NewAccountPasswordScene, ResecurePasswordScene } from '../scenes/ChangePasswordScene';
import { ChangePinScene, NewAccountPinScene, ResecurePinScene } from '../scenes/ChangePinScene';
import { PublicChangeRecoveryScene } from '../scenes/existingAccout/ChangeRecoveryScene';
import { OtpRepairScene } from '../scenes/existingAccout/OtpRepairScene';
import { SecurityAlertsScene } from '../scenes/existingAccout/SecurityAlertsScene';
import { LandingScene } from '../scenes/LandingScene';
import { LoadingScene } from '../scenes/LoadingScene';
import { NewAccountReviewScene } from '../scenes/newAccount/NewAccountReviewScene';
import { NewAccountTosScene } from '../scenes/newAccount/NewAccountTosScene';
import { NewAccountUsernameScene } from '../scenes/newAccount/NewAccountUsernameScene';
import { NewAccountWelcomeScene } from '../scenes/newAccount/NewAccountWelcomeScene';
import { OtpErrorScene } from '../scenes/OtpErrorScene';
import { PasswordLoginScene } from '../scenes/PasswordLoginScene';
import { PinLoginScene } from '../scenes/PinLoginScene';
import { RecoveryLoginScene } from '../scenes/RecoveryLoginScene';
import { WaitScene } from '../scenes/WaitScene';
import { WatchUsernames } from '../services/WatchUsernames';
export function Router(props) {
    const scene = useSelector(state => state.scene);
    const { SceneStyle } = Styles;
    function renderContent() {
        switch (scene.currentScene) {
            case 'ChangePasswordScene':
                return React.createElement(ChangePasswordScene, null);
            case 'ChangePinScene':
                return React.createElement(ChangePinScene, null);
            case 'ChangeRecoveryScene':
                return (React.createElement(PublicChangeRecoveryScene, { branding: props.branding, showHeader: props.showHeader }));
            case 'NewAccountWelcomeScene':
                return React.createElement(NewAccountWelcomeScene, { branding: props.branding });
            case 'NewAccountUsernameScene':
                return React.createElement(NewAccountUsernameScene, { branding: props.branding });
            case 'NewAccountPasswordScene':
                return React.createElement(NewAccountPasswordScene, null);
            case 'NewAccountPinScene':
                return React.createElement(NewAccountPinScene, null);
            case 'NewAccountTosScene':
                return React.createElement(NewAccountTosScene, { branding: props.branding });
            case 'NewAccountWaitScene':
                return (React.createElement(WaitScene, { title: s.strings.great_job, message: s.strings.hang_tight + '\n' + s.strings.secure_account }));
            case 'NewAccountReviewScene':
                return React.createElement(NewAccountReviewScene, null);
            case 'LandingScene':
                return React.createElement(LandingScene, { branding: props.branding });
            case 'LoadingScene':
                return React.createElement(LoadingScene, { branding: props.branding });
            case 'OtpScene':
                return React.createElement(OtpErrorScene, null);
            case 'OtpRepairScene':
                return React.createElement(OtpRepairScene, { branding: props.branding });
            case 'PasswordScene':
                return React.createElement(PasswordLoginScene, { branding: props.branding });
            case 'PinScene':
                return React.createElement(PinLoginScene, { branding: props.branding });
            case 'RecoveryLoginScene':
                return React.createElement(RecoveryLoginScene, null);
            case 'ResecurePasswordScene':
                return React.createElement(ResecurePasswordScene, null);
            case 'ResecurePinScene':
                return React.createElement(ResecurePinScene, null);
            case 'SecurityAlertScene':
                return React.createElement(SecurityAlertsScene, null);
        }
    }
    return (React.createElement(MaybeProvideLoginUi, null,
        React.createElement(View, { accessible: true, style: SceneStyle },
            React.createElement(WatchUsernames, null),
            renderContent())));
}
