import * as React from 'react';
import { asOptionalTheme } from '../../types/Theme';
import { Airship } from '../services/AirshipInstance';
import { changeTheme, getTheme, ThemeProvider } from '../services/ThemeContext';
/**
 * We use this context to determine if `LoginUiProvider` is mounted.
 */
const loginUiContext = React.createContext(false);
/**
 * Provides modals and other services for the login UI.
 * In the future, this will be our injection point for branding &
 * theme customizations.
 */
function LoginUiProviderComponent(props) {
    if (props.themeOverride != null) {
        // Error check the theme but don't use the return value as the cleaner sets missing parameters
        // to undefined which stomps on top of the oldTheme
        asOptionalTheme(props.themeOverride);
        const themeOverride = props.themeOverride;
        const oldTheme = getTheme();
        const tsHackTheme = Object.assign(Object.assign({}, oldTheme), themeOverride);
        const newTheme = tsHackTheme;
        if (JSON.stringify(oldTheme) !== JSON.stringify(newTheme)) {
            changeTheme(newTheme);
        }
    }
    return (React.createElement(loginUiContext.Provider, { value: true },
        React.createElement(ThemeProvider, null,
            React.createElement(Airship, null, props.children))));
}
export const LoginUiProvider = React.memo(LoginUiProviderComponent);
export function MaybeProvideLoginUi(props) {
    const { children } = props;
    const hasProvider = React.useContext(loginUiContext);
    return hasProvider ? children : React.createElement(LoginUiProvider, null, children);
}
