var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { FlatList, Keyboard, TouchableOpacity, TouchableWithoutFeedback, View } from 'react-native';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { sprintf } from 'sprintf-js';
import { launchPasswordRecovery, login } from '../../actions/LoginAction';
import { deleteUserFromDevice } from '../../actions/UserActions';
import s from '../../common/locales/strings';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { UserListItem } from '../abSpecific/UserListItem';
import { BackgroundImage } from '../common/BackgroundImage';
import { HeaderParentButtons } from '../common/HeaderParentButtons';
import { ButtonsModal } from '../modals/ButtonsModal';
import { showQrCodeModal } from '../modals/QrCodeModal';
import { TextInputModal } from '../modals/TextInputModal';
import { Airship, showError } from '../services/AirshipInstance';
import { connect } from '../services/ReduxStore';
import { withTheme } from '../services/ThemeContext';
import { LineFormField } from '../themed/LineFormField';
import { MainButton } from '../themed/MainButton';
class PasswordLoginSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handlePasswordChange = (password) => {
            this.setState({ errorMessage: '', password });
        };
        this.handleSubmit = () => __awaiter(this, void 0, void 0, function* () {
            const { login, saveOtpError, username } = this.props;
            const { password } = this.state;
            this.handleBlur();
            Keyboard.dismiss();
            const attempt = { type: 'password', username, password };
            yield login(attempt).catch(error => {
                if (error != null && error.name === 'OtpError') {
                    saveOtpError(attempt, error);
                }
                else {
                    console.log(error);
                    const errorMessage = error != null ? error.message : '';
                    this.setState({ errorMessage });
                }
            });
        });
        this.handleBlur = () => {
            Keyboard.dismiss();
            this.setState({
                focusFirst: false,
                focusSecond: false
            });
        };
        this.handleDelete = (username) => {
            const { deleteUserFromDevice } = this.props;
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.forget_account, message: sprintf(s.strings.forget_username_account, username), buttons: {
                    ok: { label: s.strings.forget },
                    cancel: { label: s.strings.cancel, type: 'secondary' }
                } })))
                .then((button) => __awaiter(this, void 0, void 0, function* () {
                if (button !== 'ok')
                    return;
                return yield deleteUserFromDevice(username);
            }))
                .catch(showError);
        };
        this.renderRow = (data) => {
            return (React.createElement(UserListItem, { data: data.item, onClick: this.handleSelectUser, onDelete: this.handleDelete }));
        };
        this.handleToggleUsernameList = () => {
            Keyboard.dismiss();
            this.setState({
                focusFirst: false,
                focusSecond: false,
                usernameList: !this.state.usernameList
            });
        };
        this.handleFocus1 = () => {
            this.setState({
                focusFirst: true,
                focusSecond: false
            });
        };
        this.handleFocus2 = () => {
            this.setState({
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleSetNextFocus = () => {
            this.setState({
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleSelectUser = (username) => {
            this.handleChangeUsername(username);
            this.setState({
                usernameList: false
            });
            const details = this.props.previousUsers.find(info => info.username === username);
            if (details != null &&
                (details.pinEnabled || (details.touchEnabled && this.props.touch))) {
                this.props.gotoPinLoginPage();
                return;
            }
            this.handleSetNextFocus();
        };
        this.handleChangeUsername = (data) => {
            this.setState({ errorMessage: '' });
            this.props.updateUsername(data);
        };
        this.handleForgotPassword = () => {
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, onSubmit: this.props.handlePasswordRecovery, title: s.strings.password_recovery, message: s.strings.initiate_password_recovery, inputLabel: s.strings.recovery_token })));
        };
        this.handleCreateAccount = () => {
            this.props.gotoCreatePage();
        };
        this.state = {
            errorMessage: '',
            focusFirst: true,
            focusSecond: false,
            password: '',
            usernameList: false
        };
    }
    render() {
        const { theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(KeyboardAwareScrollView, { style: styles.container, keyboardShouldPersistTaps: "always", contentContainerStyle: styles.mainScrollView },
            React.createElement(BackgroundImage, { branding: this.props.branding, content: this.renderOverImage(), onPress: this.handleBlur })));
    }
    renderOverImage() {
        const { theme } = this.props;
        const styles = getStyles(theme);
        if (this.props.loginSuccess) {
            /* return (
              <View style={style.featureBox}>
                <Text>LOGIN SUCCESS</Text>
              </View>
            ) */
            return null;
        }
        return (React.createElement(View, { style: styles.featureBoxContainer },
            React.createElement(HeaderParentButtons, { branding: this.props.branding }),
            React.createElement(TouchableWithoutFeedback, { onPress: this.handleBlur },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: this.props.branding }),
                    this.renderUsername(),
                    React.createElement(View, { style: styles.shimTiny }),
                    React.createElement(LineFormField, { testID: "passwordFormField", onChangeText: this.handlePasswordChange, value: this.state.password, label: s.strings.password, error: this.state.errorMessage, autoCorrect: false, secureTextEntry: true, returnKeyType: "go", forceFocus: this.state.focusSecond, onFocus: this.handleFocus2, onSubmitEditing: this.handleSubmit }),
                    this.renderButtons()))));
    }
    renderUsername() {
        const { theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(View, null,
            React.createElement(View, { style: styles.usernameWrapper },
                React.createElement(LineFormField, { testID: "usernameFormField", onChangeText: this.handleChangeUsername, value: this.props.username, label: s.strings.username, returnKeyType: "next", autoCorrect: false, autoFocus: this.state.focusFirst, forceFocus: this.state.focusFirst, onFocus: this.handleFocus1, onSubmitEditing: this.handleSetNextFocus }),
                React.createElement(TouchableOpacity, { style: styles.iconContainer, onPress: this.handleToggleUsernameList }, this.state.usernameList ? (React.createElement(MaterialIcon, { name: "expand-less", size: theme.rem(1), style: styles.iconColor })) : (React.createElement(MaterialIcon, { name: "expand-more", size: theme.rem(1), style: styles.iconColor })))),
            this.state.usernameList && this.renderDropdownList()));
    }
    renderDropdownList() {
        const { theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(FlatList, { style: styles.dropDownList, data: this.props.usernameOnlyList, renderItem: this.renderRow, keyExtractor: (item, index) => index.toString() }));
    }
    renderButtons() {
        const { handleQrModal, theme } = this.props;
        const styles = getStyles(theme);
        const buttonType = theme.preferPrimaryButton ? 'primary' : 'secondary';
        return (React.createElement(View, { style: styles.buttonsBox },
            React.createElement(MainButton, { type: "textOnly", onPress: this.handleForgotPassword, label: s.strings.forgot_password }),
            React.createElement(View, { style: styles.loginButtonBox },
                React.createElement(MainButton, { label: s.strings.login_button, testID: "loginButton", type: buttonType, onPress: this.handleSubmit })),
            React.createElement(MainButton, { type: "textOnly", testID: "createAccountButton", onPress: this.handleCreateAccount, label: s.strings.create_an_account }),
            React.createElement(TouchableOpacity, { onPress: handleQrModal },
                React.createElement(AntDesignIcon, { name: "qrcode", color: theme.icon, size: theme.rem(1.75) }))));
    }
}
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        width: '100%',
        height: '100%',
        backgroundColor: theme.backgroundGradientColors[0]
    },
    mainScrollView: {
        position: 'relative',
        width: '100%',
        height: '100%'
    },
    featureBoxContainer: {
        width: '100%'
    },
    featureBox: {
        position: 'relative',
        top: theme.rem(3.5),
        width: '100%',
        alignItems: 'center'
    },
    shimTiny: {
        width: '100%',
        height: theme.rem(0.75)
    },
    loginButtonBox: {
        marginVertical: theme.rem(0.25),
        width: '70%'
    },
    buttonsBox: {
        width: '100%',
        alignItems: 'center'
    },
    usernameWrapper: {
        width: '100%',
        flexDirection: 'row'
    },
    dropDownList: {
        maxHeight: theme.rem(12.5),
        backgroundColor: theme.backgroundGradientColors[0]
    },
    iconContainer: {
        position: 'absolute',
        right: 0,
        bottom: (theme.rem(16.25) - theme.rem(15.5)) * 1.6
    },
    iconColor: {
        color: theme.icon
    },
    iconColorPressed: {
        color: theme.iconDeactivated
    }
}));
export const PasswordLoginScene = connect((state) => ({
    loginSuccess: state.login.loginSuccess,
    previousUsers: state.previousUsers.userList,
    touch: state.touch.type,
    username: state.login.username,
    usernameOnlyList: state.previousUsers.usernameOnlyList
}), (dispatch) => ({
    deleteUserFromDevice(username) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(deleteUserFromDevice(username));
        });
    },
    gotoCreatePage() {
        dispatch({ type: 'NEW_ACCOUNT_WELCOME' });
    },
    gotoPinLoginPage() {
        dispatch({ type: 'START_PIN_LOGIN' });
    },
    handleQrModal() {
        Keyboard.dismiss();
        dispatch(showQrCodeModal());
    },
    login(attempt) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(login(attempt));
        });
    },
    saveOtpError(attempt, error) {
        dispatch({ type: 'OTP_ERROR', data: { attempt, error } });
    },
    updateUsername(data) {
        dispatch({ type: 'AUTH_UPDATE_USERNAME', data: data });
    },
    handlePasswordRecovery(recoveryKey) {
        return __awaiter(this, void 0, void 0, function* () {
            dispatch(launchPasswordRecovery(recoveryKey));
            return yield Promise.resolve(true);
        });
    }
}))(withTheme(PasswordLoginSceneComponent));
