import * as React from 'react';
import { Text, TouchableWithoutFeedback } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import { usePendingPress } from '../../hooks/usePendingPress';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
/**
 * A stand-alone button to perform the primary action in a modal or scene.
 */
export function PinButton(props) {
    const { children, label, onPress, testID } = props;
    // `onPress` promise logic:
    const [pending, handlePress] = usePendingPress(onPress);
    // Styles:
    const theme = useTheme();
    const styles = getStyles(theme);
    const touchableStyle = styles.keypadButton;
    const textStyle = styles.keypadText;
    const colors = theme.keypadButton;
    const start = theme.keypadButtonColorStart;
    const end = theme.keypadButtonColorEnd;
    const buttonShadow = styles.keypadButtonShadow;
    const alignSelf = 'auto';
    const dynamicStyles = Object.assign(Object.assign({ alignSelf, opacity: 1 }, sidesToMargin(mapSides(fixSides(0, 0), theme.rem))), sidesToPadding(mapSides(fixSides(0, 0), theme.rem)));
    return (React.createElement(TouchableWithoutFeedback, { style: buttonShadow, testID: testID, onPress: handlePress },
        React.createElement(LinearGradient, { colors: colors, start: start, end: end, style: [touchableStyle, dynamicStyles, styles.linearGradient] },
            label != null && !pending ? (React.createElement(Text, { adjustsFontSizeToFit: true, minimumFontScale: 0.75, numberOfLines: 1, style: textStyle }, label)) : null,
            !pending ? children : null)));
}
const getStyles = cacheStyles((theme) => {
    const commonButton = {
        alignItems: 'center',
        borderRadius: theme.rem(theme.keypadButtonBorderRadiusRem),
        flexDirection: 'row',
        justifyContent: 'center',
        width: '100%',
        minHeight: theme.rem(3)
    };
    const commonText = {
        fontFamily: theme.keypadButtonFont,
        // fontSize: theme.rem(2),
        fontSize: theme.rem(theme.keypadButtonFontSizeRem),
        marginHorizontal: theme.rem(0),
        paddingTop: theme.rem(0.5),
        paddingBottom: theme.rem(0.5),
        paddingLeft: theme.rem(0.75),
        paddingRight: theme.rem(0.75)
    };
    return {
        linearGradient: {
            // flex: 1,
            paddingLeft: 0,
            paddingRight: 0,
            borderRadius: theme.rem(theme.keypadButtonBorderRadiusRem)
        },
        keypadButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.keypadButtonOutline, borderWidth: theme.keypadButtonOutlineWidth }),
        keypadButtonShadow: Object.assign({}, theme.keypadButtonShadow),
        keypadText: Object.assign(Object.assign(Object.assign({}, commonText), theme.keypadButtonTextShadow), { color: theme.keypadButtonText })
    };
});
